@@ -386,6 +386,30 @@ class HopthruClient:
 
         return resp.json()
 
+    def get_insight_result(
+        self,
+        group_by: int,
+        date_ranges: List[Dict],
+        filters: Optional[List[Dict]] = None,
+        limit: Optional[int] = 5000,
+        offset: Optional[int] = 0,
+    ) -> Dict:
+        url = f"{self.server_url}/v1/agencies/{self.agency_id}/insights:run?limit={limit}&offset={offset}"
+
+        insight = {
+            "agencyId": str(self.agency_id),
+            "dateRanges": date_ranges,
+            "expanded": self.agency_reports_config["use_expanded_data"],
+        }
+
+        if filters is not None:
+            insight["filters"] = filters
+
+        resp = self.session.post(url, headers=self.headers, json=insight)
+        resp.raise_for_status()
+
+        return resp.json()
+
     def get_async_report_result(self, report_id: uuid.UUID) -> Dict:
         url = f"{self.server_url}/redis/status/{report_id}"
         resp = self.session.get(url, headers=self.headers)
