@@ -2028,3 +2028,87 @@ def test_get_stop_description():
 
     sent_request = httpretty.last_request()
     assert sent_request.url.endswith("description")
+
+
+@httpretty.activate
+def test_get_insight_result():
+    register_login_url()
+
+    agency_id = uuid.UUID("1dfa00fe-563f-48b6-8f6d-4101ba22fd37")
+    job_id = str(uuid.uuid4())
+
+    resp_expected = {
+        "data": {
+            "id": job_id,
+            "status": "finished",
+            "updatedAt": "2021-05-02T12:37:05",
+            "jobData": {
+                "data": [
+                    {
+                        "avgOns": 5,
+                        "sumOns": 111,
+                        "avgOffs": 3,
+                        "sumOffs": 70,
+                        "avgActivity": 8,
+                        "sumActivity": 181,
+                        "maxLoad": 16,
+                        "avgLoad": 1.62,
+                        "avgMaxLoad": 6.535,
+                        "sumPassengerDistanceTravelled": 0,
+                        "avgPassengerDistanceTravelled": 0,
+                        "boardingsPerRevenueHour": 0.01,
+                    }
+                ],
+                "insight": {
+                    "insightType": "system",
+                    "dateRanges": [
+                        {
+                            "dateRangeType": "custom",
+                            "startDate": date(2021, 1, 1).isoformat(),
+                            "endDate": date(2021, 1, 2).isoformat(),
+                            "days": [1, 1, 0, 0, 0, 0, 0],
+                        }
+                    ],
+                    "hidden": False,
+                    "isFavorited": False,
+                    "isSubscribed": False,
+                    "public": False,
+                },
+            },
+        },
+        "links": [],
+    }
+
+    httpretty.register_uri(
+        httpretty.POST,
+        f"https://api.hopthru.com/v1/agencies/{agency_id}/insights:run",
+        responses=[
+            httpretty.Response(
+                body=json.dumps(resp_expected),
+                status=200,
+            ),
+        ],
+    )
+
+    client = HopthruClient(
+        auth=UserNamePasswordAuth(username="foo", password="bar"),
+        agency_id=uuid.UUID("1dfa00fe-563f-48b6-8f6d-4101ba22fd37"),
+    )
+    resp_actual = client.get_insight_result(
+        0,
+        [
+            {
+                "dateRangeType": "custom",
+                "startDate": date(2021, 1, 1).isoformat(),
+                "endDate": date(2021, 1, 2).isoformat(),
+                "days": [1, 1, 0, 0, 0, 0, 0],
+            }
+        ],
+    )
+
+    assert resp_actual == resp_expected
+
+    sent_request = httpretty.last_request()
+    assert sent_request.url.endswith(
+        f"/v1/agencies/{agency_id}/insights:run?limit=5000&offset=0"
+    )
